@@ -13,7 +13,7 @@ from sqlalchemy.orm import joinedload
 from arpakitlib.ar_func_util import is_async_func, is_sync_func
 from arpakitlib.ar_json_util import transfer_data_to_json_str_to_data
 from project.api.api_error_codes import APIErrorCodes
-from project.api.exception import APIException
+from project.api.api_exception import APIException
 from project.core.settings import get_cached_settings
 from project.sqlalchemy_db_.sqlalchemy_db import get_cached_sqlalchemy_db
 from project.sqlalchemy_db_.sqlalchemy_model import ApiKeyDBM, UserTokenDBM
