@@ -74,7 +74,9 @@ def create_api_app(*, prefix: str = "/api") -> FastAPI:
 
     if get_cached_settings().api_enable_sqladmin:
         from project.sqladmin_.add_admin_in_app import add_sqladmin_in_app
-        add_sqladmin_in_app(app=api_app, favicon_url="/static/openapi-favicon.png")
+        add_sqladmin_in_app(
+            base_url=get_cached_settings().sqladmin_prefix, app=api_app, favicon_url="/static/openapi-favicon.png"
+        )
 
     _logger.info("finish")
 
